##  Introduction
Configure how applications, business capabilities, organizations, and other fact sheets should be mapped to corresponding dictionary items. This mapping is bidirectional, allowing you to choose the source and target systems and decide whether to sync from SAP LeanIX or SAP Signavio. We recommend using SAP LeanIX as the source for applications, business capabilities, organizations, and other elements. Dictionary items so created in SAP Signavio can then be included in the process definitions by Signavio users.
While mapping the fact sheets and dictionary items, you also configure how fact sheet attributes and corresponding fields of dictionary items should be mapped using field mapping settings. If field mappings are not set up, only the name and description are synced.
During synchronization, fact sheets and dictionary items are linked if a corresponding object with the same name already exists in the target system. If not, new fact sheets and dictionary items are created based on the source and target systems as configured by you. Additionally, any mapped attributes are continuously updated based on changes in the source system, ensuring that the information remains accurate and current across both systems.
Although the synchronization is bidirectional, SAP Signavio remains the source of truth for the relation between dictionary items and processes, and this data is always synced from SAP Signavio to SAP LeanIX.
